@@ -7,7 +7,7 @@ from config.config import ClusterConfig
 from services.common import get_graph_vertexes, get_graph_edges
 from services.sql_condition_operation import ConditionOperation
 from utils.sql_replace_operation import SqlReplaceHandler
-from celery_tasks.tasks import graph_calculation_task
+# from celery_tasks.tasks import graph_calculation_task
 
 cluster_config = ClusterConfig()
 sql_replace_handler = SqlReplaceHandler(cluster_config.is_cluster)
@@ -107,9 +107,10 @@ class ModelService(object):
         时间轴获取点边的模型
         """
         res_data = {}
+
         graph_name = data.get("subGraph")
         if not graph_name:
-            raise ValueError("subGraph param is None")
+            return
 
         db = config_param["db"]
         clickhouse_connect = config_param["clickhouse_connect"]
@@ -117,50 +118,27 @@ class ModelService(object):
         graph = CHGraph(graph_client)
         self.use_graph(graph_name, db)
 
-        """
-        获取时间限制条件
-        """
-        start_time = data.get("startTime")
-        end_time = data.get("endTime")
+        res = None
+        edges = self.graph_cfg["edges"]
+        vertexes = self.graph_cfg["vertexes"]
 
-        rest = []
-        edges = self.graph_cfg.get("edges")
-        vertexes = self.graph_cfg.get("vertexes")
-        condition_operation = ConditionOperation()
-        if "edgeConditions" in data:
-            edge_conditions = data.get("edgeConditions") or []
-            for condition in edge_conditions:
-                edge_condition_dict, edge_order_dict, special_sql_dict = condition_operation.\
-                    conditional_operation_by_one(condition, edges, start_time, end_time)
-                if "sql" in special_sql_dict:
-                    res = execute_graph_sql(graph, special_sql_dict.get("sql"), type=condition.get("type"))
-                    rest.append(res)
-        elif "nodeConditions" in data:
-            node_conditions = data.get("nodeConditions") or []
-            for condition in node_conditions:
-                node_condition_dict, node_order_dict, special_sql_dict = condition_operation.\
-                    conditional_operation_by_one(condition, vertexes, start_time, end_time)
-                if "sql" in special_sql_dict:
-                    res = execute_graph_sql(graph, special_sql_dict.get("sql"), type=condition.get("type"))
-                    rest.append(res)
-
-        if rest:
-            row_data = []
-            for item in rest:
-                result = item.get("data")
-                node_type = item.get("type")
-                schema = result.get("schema") or []
-                detail = result.get("detail") or []
-                schema.insert(0, "type")
-                if "columns" not in res_data:
-                    res_data["columns"] = schema
-
-                for ele in detail:
-                    ele.insert(0, node_type)
-                row_data.extend(detail)
-
-            res_data["rowList"] = row_data
+        if "edgeConditions" in data.keys():
+            edge_conditions = data["edgeConditions"]
+            edge_condition_dict, edge_order_dict, special_sql_dict = ConditionOperation().conditionalOperation(
+                edge_conditions, edges)
+            if "sql" in special_sql_dict:
+                res = execute_graph_sql(graph, special_sql_dict["sql"])
+        elif "nodeConditions" in data.keys():
+            node_conditions = data["nodeConditions"]
+            node_condition_dict, node_order_dict, special_sql_dict = ConditionOperation().conditionalOperation(
+                node_conditions, vertexes)
+            if "sql" in special_sql_dict:
+                res = execute_graph_sql(graph, special_sql_dict["sql"])
 
+        if res:
+            res_dict = res["data"]
+            res_data["columns"] = res_dict["schema"]
+            res_data["rowList"] = res_dict["detail"]
         # 释放链接
         disconnect_client(graph_client)
         return res_data
@@ -457,7 +435,8 @@ class ModelService(object):
             graph = CHGraph(graph_client)
         #对接计算任务接口调用
         try:
-            graph_calculation_task.delay(graph_name, task_id, compute)
+            pass
+            # graph_calculation_task.delay(graph_name, task_id, compute)
         except Exception as e:
             print(e)
             logger.error(e)
@@ -587,6 +566,7 @@ def execute_graph_sql(graph, sql, type=None, result_type=None):
     组合sql执行，返回图对象
     """
     result_dict = {}
+
     new_sql = sql_replace_handler.deal_sql(sql)
     logger.info("[execute_graph_sql] is_cluster:{}      sql:{}".format(sql_replace_handler.is_cluster, new_sql))
     res = graph.execute(new_sql)
